@@ -126,7 +126,7 @@ class Content:
     broadcastFreq = attr.ib()
 
     def __str__(self):
-        return "%s (%s, kind: %s)" % (self.title, self.uri, self.contentKind)
+        return f"{self.title} ({self.uri}, kind: {self.contentKind})"
 
 
 @attr.s
@@ -139,6 +139,15 @@ class StateInfo:
     supplement = attr.ib()
 
 
+@attr.s
+class PlayContentInfo:
+    """Playback content info."""
+
+    make = classmethod(make)
+
+    thumbnailUrl = attr.ib()
+
+
 @attr.s
 class PlayInfo:
     """Information about played content.
@@ -150,7 +159,16 @@ class PlayInfo:
     make = classmethod(make)
 
     def _make(x) -> StateInfo:
-        return StateInfo.make(**x)  # type: ignore
+        if x is not None:
+            return StateInfo.make(**x)  # type: ignore
+
+        return None
+
+    def _make_content(x) -> PlayContentInfo:
+        if x is not None:
+            return PlayContentInfo.make(**x)  # type: ignore
+
+        return None
 
     stateInfo = attr.ib(converter=_make)
     contentKind = attr.ib()
@@ -162,7 +180,6 @@ class PlayInfo:
     service = attr.ib()
     artist = attr.ib()
     albumName = attr.ib()
-    thumbnailUrl = attr.ib()
     title = attr.ib()
     durationMsec = attr.ib()
     mediaType = attr.ib()
@@ -171,6 +188,9 @@ class PlayInfo:
     repeatType = attr.ib()
     source = attr.ib()
 
+    # Documented only for "radio:" but used for Cast and Spotify too.
+    content = attr.ib(converter=_make_content)
+
     @property
     def is_idle(self):
         """Return if content is being played."""
@@ -179,6 +199,9 @@ class PlayInfo:
     @property
     def state(self):
         """Return playback state."""
+        if self.stateInfo is None:
+            return None
+
         return self.stateInfo.state
 
     @property
@@ -194,7 +217,7 @@ class PlayInfo:
             return timedelta(milliseconds=self.positionMsec)
 
     def __str__(self):
-        return "%s (%s/%s), state %s" % (
+        return "{} ({}/{}), state {}".format(
             self.title,
             self.position,
             self.duration,
@@ -279,7 +302,7 @@ class Source:
     outputs = attr.ib()
 
     def __str__(self):
-        s = "%s (%s)" % (self.title, self.source)
+        s = f"{self.title} ({self.source})"
         if self.outputs is not None:
             s += " - outs: %s" % self.outputs
         return s
@@ -306,13 +329,13 @@ class Volume:
 
     def __str__(self):
         if self.output and self.output.rfind("=") > 0:
-            s = "Zone %s Volume: %s/%s" % (
+            s = "Zone {} Volume: {}/{}".format(
                 self.output[self.output.rfind("=") + 1 :],
                 self.volume,
                 self.maxVolume,
             )
         else:
-            s = "Volume: %s/%s" % (self.volume, self.maxVolume)
+            s = f"Volume: {self.volume}/{self.maxVolume}"
         if self.is_muted:
             s += " (muted)"
         return s
@@ -379,7 +402,7 @@ class Zone:
     iconUrl = attr.ib()
 
     def __str__(self):
-        s = "%s (uri: %s)" % (self.title, self.uri)
+        s = f"{self.title} (uri: {self.uri})"
         if self.active:
             s += " (active)"
         return s
@@ -409,7 +432,7 @@ class Input:
     outputs = attr.ib(default=attr.Factory(list))
 
     def __str__(self):
-        s = "%s (uri: %s)" % (self.title, self.uri)
+        s = f"{self.title} (uri: {self.uri})"
         if self.active:
             s += " (active)"
         return s
@@ -448,7 +471,7 @@ class Storage:
     position = attr.ib()
 
     def __str__(self):
-        return "%s (%s) in %s (%s/%s free), available: %s, mounted: %s" % (
+        return "{} ({}) in {} ({}/{} free), available: {}, mounted: {}".format(
             self.deviceName,
             self.uri,
             self.position,
@@ -516,7 +539,7 @@ class SettingsEntry:
     deviceUIInfo = attr.ib()
 
     def __str__(self):
-        return "%s (%s, %s)" % (self.title, self.titleTextID, self.type)
+        return f"{self.title} ({self.titleTextID}, {self.type})"
 
 
 @attr.s
